/***************************************
A simple demonstration of serial communications which
incorporates the on-board hardware USART of the Microchip
PIC16F886 device. 
1) The project sends ASCII numbers 1-9 out to the terminal once
	followed by a carriage return and new line command.
2) Then it sends the ASCII values for A-Z once followed by
	a carriage return and new line command.
3) Then it will send the word "Hello" out once.
4) Then it will use the printf command to send phrases and 
	ask for you to send it something via the keyboard and it will
	echo it back.
The program will keep asking for input until power is lost.

Option 1: Hyperterminal and USB to RS232 module

Pin 0(C7) Rx - to Tx of USB/RS232 module
Pin 1(C6) Tx - to Rx of USB/RS232 module 

Hyperterminal settings
Bits per second: 9600
Data bits: 8
Parity: None
Stop bits: 1
Flow control: None

Option 2: PICkit 2 as interface and running UART tool 

B5 to PICkit 2 pin 5
B7 to PICkit 2 pin 4
Vdd to PICkit 2 pin 2
Gnd to PICkit 2 pin 3
****************************************/
#define _LEGACY_HEADERS //Added for compiler versions 9.81+
#include "simplec1.1.h"

void main(void){
	
	init_micro();		// Setup micro ports	
	init_serial(9600);	// set up the USART baud rate (2400 or 9600)

	// *** Serial Communication Main Loop	

	while(1)
		{
		
	// *********** Send a decimal numbers from 1 to 9 *******
		for (char count = 0x31; count <= 0x39; count = count +1)	
			{
			putch(count);		// Send Count 1-9 in ASCII
			pause(100);			// Delay 100 msec
			}		
			putch(0x0D);		// Send ASCII value for carriage return 
			putch(0x0A);		// Send ASCII value for new line
	
	// ********** Send the alphabet from A to Z ***********

		for (char count = 0x41; count <= 0x5A; count = count +1)	
			{
			putch(count);		// Send Count 1-9 in ASCII
			pause(100);			// Delay 100 msec
			}	
			putch(0x0D);		// Send ASCII value for carriage return 
			putch(0x0A);		// Send ASCII value for new line
	
	// ************** Send a string of characters *****************
		char txt[] ="Hello";
		for (char x = 0; x<5; x++)
			{
			putch (txt[x]);
			}
		putch(0x0D);		// Send ASCII value for carriage return 
		putch(0x0A);		// Send ASCII value for new line

	// ********** Use printf command to ask for input and echo it back *******
		while(1)
			{	
			printf("Press a key and I will echo it back:\r\n");
			char input = getch();	// read a response from the user
			printf("I detected [%c]\r\n",input);	// echo it back
			}
		}
}
